==> iTop-3.2.0-2-14758.zip: web/dictionaries/ui/pages/preferences/it.dictionary.itop.preferences.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('IT IT', 'Italian', 'Italiano', [
	'UI:Favorites:General:ShowSummaryCards' => 'Mostra le schede di riepilogo',
	'UI:Favorites:General:ShowSummaryCards+' => 'Quando si passa il mouse su un collegamento che punta a un oggetto, visualizza un breve riepilogo dell\'oggetto, se disponibile per quella classe',
	'UI:Preferences:ActivityPanel:EntryFormOpened' => 'Modulo di immissione aperto per impostazione predefinita',
	'UI:Preferences:ActivityPanel:EntryFormOpened+' => 'Se il modulo di immissione sarà aperto durante la visualizzazione di un oggetto. Se non selezionato, sarà comunque possibile aprirlo facendo clic sul pulsante di composizione',
	'UI:Preferences:ActivityPanel:Title' => 'Pannello attività',
	'UI:Preferences:ChooseAPlaceholder' => 'Seleziona un\'immagine placeholder utente',
	'UI:Preferences:ChooseAPlaceholder+' => 'Scegli un\'immagine placeholder che verrà visualizzata se il contatto associato al tuo utente non ne ha una',
	'UI:Preferences:ChooseAPlaceholder:Success:Message' => 'Your placeholder image has been successfully updated~~',
	'UI:Preferences:General:Theme' => 'Tema',
	'UI:Preferences:General:Theme:DefaultThemeLabel' => '%1$s (predefinito)',
	'UI:Preferences:General:Title' => 'Generale',
	'UI:Preferences:General:Toasts' => 'Toast notifications position~~',
	'UI:Preferences:General:Toasts:Bottom' => 'Bottom~~',
	'UI:Preferences:General:Toasts:Top' => 'Top~~',
	'UI:Preferences:Lists:Title' => 'Liste',
	'UI:Preferences:Notifications' => 'Notifications~~',
	'UI:Preferences:Notifications+' => 'Configure the notifications you want to receive <a href="%1$s">on this page</a>.~~',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset' => 'Reimposta',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset:Tooltip' => 'Torna alle scorciatoie da tastiera predefinite',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Tooltip' => 'Registra una scorciatoia da tastiera',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Input:Hint' => 'Digitare una scorciatoia da tastiera',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Title' => 'Scorciatoie da tastiera dell\'applicazione',
	'UI:Preferences:RichText:Title' => 'Editor di testo ricco',
	'UI:Preferences:RichText:ToolbarState' => 'Stato predefinito della barra degli strumenti',
	'UI:Preferences:RichText:ToolbarState:Collapsed' => 'Compressa',
	'UI:Preferences:RichText:ToolbarState:Expanded' => 'Espansa',
	'UI:Preferences:Tabs:Layout:Horizontal' => 'Orizzontale',
	'UI:Preferences:Tabs:Layout:Label' => 'Layout',
	'UI:Preferences:Tabs:Layout:Vertical' => 'Verticale',
	'UI:Preferences:Tabs:Scrollable:Classic' => 'Classica',
	'UI:Preferences:Tabs:Scrollable:Label' => 'Navigazione',
	'UI:Preferences:Tabs:Scrollable:Scrollable' => 'Scorrevole',
	'UI:Preferences:Tabs:Title' => 'Schede',
	'UI:Preferences:Title' => 'Preferenze',
	'UI:Preferences:UserInterface:Title' => 'Interfaccia utente',
]);

==> iTop-3.2.1-1-16749.zip: web/dictionaries/ui/pages/preferences/it.dictionary.itop.preferences.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('IT IT', 'Italian', 'Italiano', array(
	'UI:Preferences:Title' => 'Preferenze',
	'UI:Preferences:UserInterface:Title' => 'Interfaccia utente',
	'UI:Preferences:General:Title' => 'Generale',
	'UI:Preferences:General:Theme' => 'Tema',
	'UI:Preferences:General:Theme:DefaultThemeLabel' => '%1$s (predefinito)',
	'UI:Favorites:General:ShowSummaryCards' => 'Mostra le schede di riepilogo',
	'UI:Favorites:General:ShowSummaryCards+' => 'Quando si passa il mouse su un collegamento che punta a un oggetto, visualizza un breve riepilogo dell\'oggetto, se disponibile per quella classe',
	'UI:Preferences:Lists:Title' => 'Liste',
	'UI:Preferences:RichText:Title' => 'Editor di testo ricco',
	'UI:Preferences:RichText:ToolbarState' => 'Stato predefinito della barra degli strumenti',
	'UI:Preferences:RichText:ToolbarState:Expanded' => 'Espansa',
	'UI:Preferences:RichText:ToolbarState:Collapsed' => 'Compressa',
	'UI:Preferences:ActivityPanel:Title' => 'Pannello attività',
	'UI:Preferences:ActivityPanel:EntryFormOpened' => 'Modulo di immissione aperto per impostazione predefinita',
	'UI:Preferences:ActivityPanel:EntryFormOpened+' => 'Se il modulo di immissione sarà aperto durante la visualizzazione di un oggetto. Se non selezionato, sarà comunque possibile aprirlo facendo clic sul pulsante di composizione',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Title' => 'Scorciatoie da tastiera dell\'applicazione',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Input:Hint' => 'Digitare una scorciatoia da tastiera',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Tooltip' => 'Registra una scorciatoia da tastiera',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset' => 'Reimposta',
	'UI:Preferences:PersonalizeKeyboardShortcuts:Button:Reset:Tooltip' => 'Torna alle scorciatoie da tastiera predefinite',
	'UI:Preferences:Tabs:Title' => 'Schede',
	'UI:Preferences:Tabs:Layout:Label' => 'Layout',
	'UI:Preferences:Tabs:Layout:Horizontal' => 'Orizzontale',
	'UI:Preferences:Tabs:Layout:Vertical' => 'Verticale',
	'UI:Preferences:Tabs:Scrollable:Label' => 'Navigazione',
	'UI:Preferences:Tabs:Scrollable:Classic' => 'Classica',
	'UI:Preferences:Tabs:Scrollable:Scrollable' => 'Scorrevole',
	'UI:Preferences:General:Toasts' => 'Toast notifications position~~',
	'UI:Preferences:General:Toasts:Bottom' => 'Bottom~~',
	'UI:Preferences:General:Toasts:Top' => 'Top~~',
	'UI:Preferences:ChooseAPlaceholder' => 'Seleziona un\'immagine placeholder utente',
	'UI:Preferences:ChooseAPlaceholder+' => 'Scegli un\'immagine placeholder che verrà visualizzata se il contatto associato al tuo utente non ne ha una',
	'UI:Preferences:ChooseAPlaceholder:Success:Message' => 'Your placeholder image has been successfully updated~~',
	'UI:Preferences:Notifications' => 'Notifications~~',
	'UI:Preferences:Notifications+' => 'Configure the notifications you want to receive <a href="%1$s">on this page</a>.~~',
	
));
